Module logger

Module logger 

Structs

FileConfig
Configuration for file-based logging.
StdConfig
Configuration for standard stream logging.

Enums

LogEventLevel
Log level for filtering log events.
StdTarget
Target for standard stream output.

Functions

logger_configure_file
Configures the global logger to write to a file in JSON format.
logger_configure_std
Configures the global logger to write to stdout or stderr in compact format.
logger_disable_file
Disables file logging for the global logger.
logger_disable_std
Disables standard stream logging for the global logger.
logger_set_log_level
Sets the minimum log level for the global logger.

Type Aliases

Error