pub struct FileWriter { /* private fields */ }Expand description
A non-blocking writer that writes log output to a file.
Uses a background thread to handle writes asynchronously, which improves
performance by not blocking the logging thread. The background thread is
managed by the internal WorkerGuard.
Implementations
Sourceimpl FileWriter
impl FileWriter
Sourcepub fn new(config: &FileConfig) -> Result<Self>
pub fn new(config: &FileConfig) -> Result<Self>
Creates a new file writer that writes to the specified path.
If the parent directory doesn’t exist, it will be created. The file will be opened in append mode. If size_bytes is specified in the config, the file will be rotated when it reaches that size.